.saveFileDialog .fileNameInput {
    width: 140px;
}

.saveFileDialog .input-line {
    display: flex;
    margin-left: 0px;
    margin-top: 10px;
}

.saveFileDialog .input-line .input-elem {
    margin-top: 0;
    margin-bottom: 0;
    margin-right: 4px;
}

.modal .saveFileDialog .sq-fieldset legend {
    margin-bottom: 0px;
}

.saveFileDialog .input-line>a,
.saveFileDialog .input-line>label:last-child {
    margin-top: 2px;
    font-size: 12px;
    width: 40px;
    font-weight: 400;
}

.modal .saveFileDialog .input-line {
    display: flex;
}

.modal .saveFileDialog .input-line .sqn-label {
    width: 70px;
}

.modal .saveFileDialog .input-line .sqn-input {
    flex: 1 1 auto;
}